from .brcode import *


__short_description__ = (
    "Extração valores BRCODE - "
    
)
__license__ = "MIT"
__author__ = "Alexandre Mulina"
__author_email__ = "alexandremulina@hotmail.com"
__maintainer__ = "Alexandre Mulina"
__maintainer_email__ = "alexandremulina@hotmail.com"
__github_username__ = "alexandremulina"
